@@ -7,18 +7,20 @@
 # You may use and distribute this software under the same terms and conditions
 # as Perl itself.
 
-package PkgConfig::Vars;
+package
+    PkgConfig::Vars;
 # this is a namespace for .pc files to hold their variables without
 # relying on lexical scope.
 
-package PkgConfig::UDefs;
+package
+    PkgConfig::UDefs;
 # This namespace provides user-defined variables which are to override any
 # declarations within the .pc file itself.
 
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.07520_04';
+our $VERSION = '0.07920_01';
 
 require 5.006;
 
@@ -456,7 +458,19 @@ sub find {
     
         foreach my $lib (@libraries) {
             $o->recursion(0);
+            my($op,$ver);
+            ($lib,$op,$ver) = ($1,$2,PkgConfig::Version->new($3))
+                if $lib =~ /^(.*)\s+(!=|=|>=|<=|>|<)\s+(.*)$/;
             $o->find_pcfile($lib);
+            
+            if(!$o->errmsg && defined $op) {
+                $op = '==' if $op eq '=';
+                unless(eval qq{ PkgConfig::Version->new(\$o->pkg_version) $op \$ver })
+                {
+                    $o->errmsg("Requested '$lib $op $ver' but version of $lib is " . 
+                        ($o->pkg_version ? $o->pkg_version : '') . "\n");
+                }
+            }
         }
     }
     
@@ -733,6 +747,11 @@ sub get_ldflags {
     return @ret;
 }
 
+sub get_var {
+    my($self, $name) = @_;
+    $self->_pc_var($name);
+}
+
 sub get_list {
     my $self = shift;
     my @search_paths = @{$self->search_path};
@@ -840,6 +859,34 @@ if(caller) {
     return 1;
 }
 
+package
+    PkgConfig::Version;
+
+use overload
+    '<=>' => sub { $_[0]->cmp($_[1]) },
+    '""'  => sub { $_[0]->as_string },
+    fallback => 1;
+
+sub new {
+    my($class, $value) = @_;
+    bless [split /\./, defined $value ? $value : ''], $class;
+}
+
+sub clone {
+    __PACKAGE__->new(shift->as_string);
+}
+
+sub as_string {
+    my($self) = @_;
+    join '.', @{ $self };
+}
+
+sub cmp {
+    my($self, $other) = @_;
+    no warnings 'uninitialized';
+    defined($self->[0]) || defined($other->[0]) ? ($self->[0] <=> $other->[0]) || &cmp([@{$self}[1..$#$self]], [@{$other}[1..$#$other]]) : 0;
+}
+
 ################################################################################
 ################################################################################
 ################################################################################
@@ -877,6 +924,7 @@ GetOptions(
     'list-all' => \my $ListAll,
     'static' => \my $UseStatic,
     'cflags' => \my $PrintCflags,
+    'cflags-only-I' => \my $PrintCflagsOnlyI,
     'exists' => \my $PrintExists,
     'atleast-version=s' => \my $AtLeastVersion,
     'exact-version=s'   => \my $ExactVersion,
@@ -938,7 +986,7 @@ if($SilenceErrors) {
     $quiet_errors = 1;
 }
 
-my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintLibsOnlyl || $PrintVersion);
+my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintCflagsOnlyI || $PrintLibsOnlyl || $PrintVersion);
 
 if($WantFlags) {
     $quiet_errors = 0 unless $SilenceErrors;
@@ -977,6 +1025,15 @@ if($ListAll) {
 }
 
 my @FINDLIBS = @ARGV or die "Must specify at least one library";
+
+if($AtLeastVersion) {
+    @FINDLIBS = map { "$_ >= $AtLeastVersion" } @FINDLIBS;
+} elsif($MaxVersion) {
+    @FINDLIBS = map { "$_ <= $MaxVersion" } @FINDLIBS;
+} elsif($ExactVersion) {
+    @FINDLIBS = map { "$_ = $ExactVersion" } @FINDLIBS;
+}
+
 my $o = PkgConfig->find(\@FINDLIBS, %pc_options);
 
 if($o->errmsg) {
@@ -984,31 +1041,6 @@ if($o->errmsg) {
     exit(1);
 }
 
-if($ExactVersion) {
-    exit(2) unless $o->pkg_version eq $ExactVersion;
-}
-
-sub _is_greater_than_or_equal ($$)
-{
-    my @a = split /\./, shift;
-    my @b = split /\./, shift;
-    while(@a || @b) {
-        my $a = shift(@a) || 0;
-        my $b = shift(@b) || 0;
-        return 1 if $a > $b;
-        return 0 if $a < $b;
-    }
-    return 1;
-}
-
-if($AtLeastVersion) {
-    exit(2) unless _is_greater_than_or_equal($o->pkg_version, $AtLeastVersion);
-}
-
-if($MaxVersion) {
-    exit(2) unless _is_greater_than_or_equal($MaxVersion, $o->pkg_version);
-}
-
 if($o->print_variables) {
     while (my ($k,$v) = each %{$o->defined_variables}) {
         print $k;
@@ -1034,12 +1066,18 @@ if($PrintVersion) {
     exit(0);
 }
 
+my @print_flags;
+
 if($PrintCflags) {
-    print join(" ", $o->get_cflags) . " ";
+    @print_flags = $o->get_cflags;
+}
+
+if($PrintCflagsOnlyI) {
+    @print_flags = grep /^-I/, $o->get_cflags;
 }
 
 if($PrintLibs) {
-    print join(" ", $o->get_ldflags) . " ";
+    @print_flags = $o->get_ldflags;
 }
 
 # handle --libs-only-L and --libs-only-l but watch the case when
@@ -1047,11 +1085,12 @@ if($PrintLibs) {
 # 'ppkg-config --libs-only-l foo'
 
 if($PrintLibsOnlyl or ($PrintLibsOnlyl and $PrintLibsOnlyL)) {
-    print grep /^-l/, $o->get_ldflags;
+    @print_flags = grep /^-l/, $o->get_ldflags;
 } elsif ($PrintLibsOnlyL) {
-    print grep /^-[LR]/, $o->get_ldflags;
+    @print_flags = grep /^-[LR]/, $o->get_ldflags;
 }
 
+print $_, " " for @print_flags;
 print "\n";
 exit(0);
 
@@ -1093,6 +1132,7 @@ Compare to:
     if($o->errmsg) {
         #handle error
     } else {
+        my $prefix = $o->get_var('prefix');
         my @cflags = $o->get_cflags;
         my @ldflags = $o->get_ldflags;
     }
@@ -1106,7 +1146,7 @@ This is not a description of the uses of C<pkg-config> but rather a description
 of the differences between the C version and the Perl one.
 
 While C<pkg-config> is a compiled binary linked with glib, the pure-perl version
-has no such requirement, and will run wherever Perl ( >= 5.04 ) does.
+has no such requirement, and will run wherever Perl ( >= 5.6 ) does.
 
 The main supported options are the common C<--libs>, C<--cflags>,
 C<--static>, C<--exists> and C<--modversion>.
@@ -1216,8 +1256,8 @@ C<--silence-errors>
 
 =head3 ENVIRONMENT
 
-the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited list
-of directories with contain C<.pc> files.
+the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited 
+(semicolon-delimited on Windows) list of directories with contain C<.pc> files.
 
 =head2 MODULE OPTIONS
 
@@ -1304,6 +1344,10 @@ The version of the package
 
 Returns a list of compiler and linker flags, respectively.
 
+=head4 I<< $o->get_var($name) >>
+
+Get the variable with the given name.
+
 =head4 I<< PkgConfig->Guess >>
 
 This is a class method, and will replace the hard-coded default linker and include
@@ -1346,6 +1390,10 @@ Example, don't install any scripts:
 
  % perl Makefile.PL --script none
 
+You can also set the environment variable PERL_PKG_CONFIG_SCRIPTS to the
+desired --script value (separating each script name with a comma C<,>) to
+ensure that upgrades of PkgConfig do the same.
+
 =head2 CAVEATS
 
 On Strawberry Perl C<ppkg-config> acts like Strawberry is the system.  
@@ -1368,7 +1416,7 @@ As of Strawberry 5.20.0.1 PkgConfig is bundled with Strawberry and
 C<pkg-config> is installed by default (in addition to C<ppkg-config>,
 though the C<ppkg-config> alias is NOT bundled with Strawberry itself).
 
-For details on how to patch the .pc fils bundled with older Strawberries,
+For details on how to patch the .pc files bundled with older Strawberries,
 see the C<README.win32> that comes with this Distribution.
 
 =head2 BUGS
@@ -1383,12 +1431,34 @@ package itself (without dependencies).
 
 =head1 SEE ALSO
 
-L<ExtUtils::PkgConfig>, a wrapper around the C<pkg-config> binary
+=over 4
 
-L<pkg-config|http://www.freedesktop.org/wiki/Software/pkg-config>
+=item L<pkg-config|http://www.freedesktop.org/wiki/Software/pkg-config>
 
-L<http://www.openbsd.org/cgi-bin/cvsweb/src/usr.bin/pkg-config/> another 
-perl implementation of pkg-config
+The original C implementation
+
+=item L<ExtUtils::PkgConfig>
+
+A wrapper around the C<pkg-config> binary that can be used in your C<Makefile.PL>
+or C<Build.PL>.
+
+=item L<http://www.openbsd.org/cgi-bin/cvsweb/src/usr.bin/pkg-config/>
+
+Another perl implementation of pkg-config
+
+=item L<pkgconf|https://github.com/pkgconf/pkgconf>
+
+An alternative C implementation
+
+=item L<pkg-config|https://github.com/ruby-gnome2/pkg-config>
+
+Pure Ruby implementation.
+
+=item L<pykg-config|https://pypi.python.org/pypi/pykg-config/1.2.0>
+
+A Python implementation.
+
+=back
 
 =head1 AUTHOR
 
